@@ -66,6 +66,10 @@
 #define CHANGED(...) \
     PDL_ACCUMERROR(PDL_err, pdl_changed(__VA_ARGS__))
 
+#define PDL_RECURSE_CHECK(var) \
+  if (var > 1000) \
+    return pdl_make_error_simple(PDL_EUSERERROR, "PDL:Internal Error: data structure recursion limit exceeded (max 1000 levels)\n\tThis could mean that you have found an infinite-recursion error in PDL, or\n\tthat you are building data structures with very long dataflow dependency\n\tchains.  You may want to try using sever() to break the dependency.\n")
+
 extern Core PDL;
 
 pdl_error pdl__make_physical_recprotect(pdl *it, int recurse_count);
@@ -348,10 +352,6 @@ pdl_error pdl_destroytransform(pdl_trans *trans, int ensure, int recurse_count)
   if (!vtable)
     return pdl_make_error(PDL_EFATAL, "ZERO VTABLE DESTTRAN 0x%p %d\n",trans,ensure);
   char ismutual = (trans->flags & PDL_ITRANS_DO_DATAFLOW_ANY);
-  if (!ismutual) for(j=0; j<vtable->nparents; j++) {
-    if (!trans->pdls[j]) return pdl_make_error(PDL_EFATAL, "NULL pdls[%td] in %s", j, vtable->name);
-    if (trans->pdls[j]->state & PDL_DATAFLOW_ANY) { ismutual=1; break; }
-  }
   PDLDEBUG_f(printf("pdl_destroytransform %s=%p (ensure=%d ismutual=%d)\n",
     vtable->name,trans,ensure,(int)ismutual));
   if (ensure)
@@ -618,8 +618,7 @@ pdl_error pdl__addchildtrans(pdl *it,pdl_trans *trans)
 
 pdl_error pdl__make_physdims_recprotect(pdl *it, int recurse_count) {
   pdl_error PDL_err = {0, NULL, 0};
-  if (recurse_count > 1000)
-    return pdl_make_error_simple(PDL_EUSERERROR, "PDL:Internal Error: data structure recursion limit exceeded (max 1000 levels)\n\tThis could mean that you have found an infinite-recursion error in PDL, or\n\tthat you are building data structures with very long dataflow dependency\n\tchains.  You may want to try using sever() to break the dependency.\n");
+  PDL_RECURSE_CHECK(recurse_count);
   if (!it) return pdl_make_error_simple(PDL_EFATAL, "make_physdims called with NULL");
   PDLDEBUG_f(printf("make_physdims %p state=", it);pdl_dump_flags_fixspace(it->state, 0, PDL_FLAGS_PDL));
   PDL_CHKMAGIC(it);
@@ -642,33 +641,31 @@ pdl_error pdl_make_physdims(pdl *it) {
   return pdl__make_physdims_recprotect(it, 0);
 }
 
-static inline pdl_error pdl_trans_flow_null_checks(pdl_trans *trans, int *ret) {
+static inline char _trans_forward_only(pdl *p) {
+  pdl_trans *tp = p->trans_parent;
+  return !!(tp && (tp->flags & PDL_ITRANS_DO_DATAFLOW_ANY) == PDL_ITRANS_DO_DATAFLOW_F);
+}
+static inline pdl_error pdl_trans_flow_null_checks(pdl_trans *trans, char *disable_back) {
   pdl_error PDL_err = {0, NULL, 0};
-  int pfflag=0;
   PDL_Indx i;
   pdl_transvtable *vtable = trans->vtable;
-/* Then, set our children. This is: */
-/* First, determine whether any of our children already have
- * a parent, and whether they need to be updated. If this is
- * the case, we need to do some thinking. */
-  for(i=0; i<vtable->nparents; i++) {
-    int state = trans->pdls[i]->state;
-    if (state & PDL_NOMYDIMS)
+  char input_forward_only = 0;
+  for (i=0; i<vtable->nparents; i++) {
+    pdl *parent = trans->pdls[i];
+    if (_trans_forward_only(parent))
+      input_forward_only = 1;
+    if (parent->state & PDL_NOMYDIMS)
       return pdl_make_error(PDL_EUSERERROR,
 	"Error in %s: input parameter '%s' is null",
 	vtable->name, vtable->par_names[i]
       );
-    if(state & PDL_DATAFLOW_ANY) pfflag++;
   }
-  for(; i<vtable->npdls; i++) {
-/* If children are flowing, croak. It's too difficult to handle properly */
-    if(trans->pdls[i]->state & PDL_DATAFLOW_ANY)
-	return pdl_make_error_simple(PDL_EUSERERROR, "Sorry, cannot flowing families right now\n");
-/* Same, if children have trans yet parents are flowing */
-    if(trans->pdls[i]->trans_parent && pfflag)
-	return pdl_make_error_simple(PDL_EUSERERROR, "Sorry, cannot flowing families right now (2)\n");
+  for (; i<vtable->npdls; i++) {
+    pdl *child = trans->pdls[i];
+    if (_trans_forward_only(child))
+      return pdl_make_error(PDL_EUSERERROR, "%s: cannot output to parameter '%s' with inward but no backward flow", vtable->name, vtable->par_names[i]);
   }
-  *ret = pfflag;
+  *disable_back = input_forward_only;
   return PDL_err;
 }
 
@@ -690,24 +687,24 @@ pdl_error pdl_make_trans_mutual(pdl_trans *trans)
     outputs - cf type_coerce */
   for (i=vtable->nparents; i<vtable->npdls; i++) pdls[i] = pdls[i+nchildren];
   PDL_TR_CHKMAGIC(trans);
-  int pfflag=0;
-  PDL_err = pdl_trans_flow_null_checks(trans, &pfflag);
+  char disable_back = 0;
+  PDL_err = pdl_trans_flow_null_checks(trans, &disable_back);
   if (PDL_err.error) {
     PDL_ACCUMERROR(PDL_err, pdl_trans_finaldestroy(trans));
     return PDL_err;
   }
-  char dataflow = !!(pfflag || (trans->flags & PDL_ITRANS_DO_DATAFLOW_ANY));
-  PDLDEBUG_f(printf("make_trans_mutual dataflow=%d\n", (int)dataflow));
   for (i=0; i<nparents; i++) {
     pdl *parent = pdls[i];
     PDL_RETERROR(PDL_err, pdl__addchildtrans(parent,trans));
     if (parent->state & PDL_DATAFLOW_F) {
-      if (!(parent->trans_parent && (parent->trans_parent->flags & PDL_ITRANS_DO_DATAFLOW_F))) /* not inherently flowing */
-        parent->state &= ~PDL_DATAFLOW_F;
+      parent->state &= ~PDL_DATAFLOW_F;
       trans->flags |= PDL_ITRANS_DO_DATAFLOW_F;
-      dataflow = 1;
     }
   }
+  char dataflow = !!(trans->flags & PDL_ITRANS_DO_DATAFLOW_ANY);
+  PDLDEBUG_f(printf("make_trans_mutual dataflow=%d disable_back=%d\n", (int)dataflow, (int)disable_back));
+  if (dataflow && disable_back)
+    trans->flags &= ~PDL_ITRANS_DO_DATAFLOW_B;
   char wasnull[npdls];
   for (i=nparents; i<npdls; i++) {
     pdl *child = pdls[i];
@@ -790,8 +787,7 @@ pdl_error pdl_redodims_default(pdl_trans *trans) {
 pdl_error pdl__make_physical_recprotect(pdl *it, int recurse_count) {
 	pdl_error PDL_err = {0, NULL, 0};
 	int i, vaffinepar=0;
-	if (recurse_count > 1000)
-	  return pdl_make_error_simple(PDL_EUSERERROR, "PDL:Internal Error: data structure recursion limit exceeded (max 1000 levels)\n\tThis could mean that you have found an infinite-recursion error in PDL, or\n\tthat you are building data structures with very long dataflow dependency\n\tchains.  You may want to try using sever() to break the dependency.\n");
+	PDL_RECURSE_CHECK(recurse_count);
 	PDLDEBUG_f(printf("make_physical %p\n",(void*)it));
 	pdl_trans *trans = it->trans_parent;
 	PDL_CHKMAGIC(it);
