@@ -84,6 +84,11 @@ course that takes you from a complete beginner level to expert.
 List of all available documentation, sorted alphabetically. If you
 cannot find what you are looking for, try here.
 
+=item L<PDL::DeveloperGuide>
+
+A guide for people who want to contribute to PDL.  Contributions are
+very welcome!
+
 =back
 
 =head1 DATA TYPES
@@ -156,7 +161,7 @@ start-up modules.
 =cut
 
 # set the version:
-our $VERSION = '2.088';
+our $VERSION = '2.090';
 
 # Main loader of standard PDL package
 
@@ -208,7 +213,7 @@ our $no_clone_skip_warning = 0;
 sub CLONE_SKIP {
     warn <<'EOF' if !$no_clone_skip_warning;
 * If you need to share PDL data across threads, use memory mapped data, or
-* check out PDL::ParallelCPU, available on CPAN.
+* check out PDL::Parallel::threads, available on CPAN.
 * You can silence this warning by saying `$PDL::no_clone_skip_warning = 1;'
 * before you create your first thread.
 EOF
