@@ -115,6 +115,7 @@ sub init_converter_table {
 		 ['PS','pnmtops -dpi=100',
 		  'pstopnm -stdout -xborder=0 -yborder=0 -quiet -dpi=100'],
 		 ['GIF','ppmtogif','giftopnm'],
+		 ['XBM','pbmtoxbm','xbmtopbm'],
 		 ['IFF','ppmtoilbm','ilbmtoppm']
 		 );
   push(@special,['JPEG', 'cjpeg' ,'djpeg'])
@@ -268,11 +269,11 @@ sub PDL::rpic {
     }
 
     my $fh;
-    if ($converter{$type}->{'get'} =~ /^NONE/) {
+    if ($converter{$type}->{'get'} and $converter{$type}->{'get'} =~ /^NONE/) {
       open $fh, $file;
     } else {
-      my @cmd = $converter{$type}->{get};
-      push @cmd, shellwords $converter{$type}->{FLAGS} // $Dflags;
+      my @cmd = $converter{$type}{get} // barf "No converter for '$type'";
+      push @cmd, shellwords $converter{$type}{FLAGS} // $Dflags;
       push @cmd, shellwords $$hints{XTRAFLAGS} if defined($$hints{XTRAFLAGS});
       open $fh, '-|', @cmd, $file
         or barf "spawning '@cmd' failed: $? ($!)";
@@ -769,7 +770,10 @@ sub PDL::wmpeg {
          map int(($MDims[$_]-$Dims[$_])/2).':'.
             int(($MDims[$_]+$Dims[$_])/2-1),0..2);
    local $SIG{PIPE} = 'IGNORE';
-   open my $fh, '|-', qw(ffmpeg -loglevel quiet -f image2pipe -codec:v ppm -i -), $file
+   my $loglevel = 'quiet';
+   $loglevel = 'verbose' if $PDL::verbose;
+   $loglevel = 'debug' if $PDL::debug;
+   open my $fh, '|-', qw(ffmpeg -y -loglevel), $loglevel, qw(-f image2pipe -codec:v ppm -i -), $file
       or barf "spawning ffmpeg failed: $?";
    binmode $fh;
    for ($pdl->dog) {
@@ -786,7 +790,7 @@ sub PDL::wmpeg {
 Figure out the format of an image file from its magic numbers, or else, from its extension.
 
 Currently recognized image formats are: PNM, GIF, TIFF, JPEG, SGI,
-RAST, IFF, PCX, PS, FITS, PNG.  If the format can not be determined,
+RAST, IFF, PCX, PS, FITS, PNG, XBM.  If the format can not be determined,
 the string 'UNKNOWN' is returned.
 
 =for example
@@ -855,6 +859,7 @@ sub chkext {
 	return 'PS'   if $ext =~ /^ps/;
 	return 'FITS' if $ext =~ /^f(i?ts|it)$/;
 	return 'PNG'  if $ext =~ /^png$/i;
+	return 'XBM'  if $ext =~ /^xbm$/i;
     }
 
 
@@ -893,6 +898,7 @@ sub chkform {
     return 'PS'   if $magic =~ /%!\s*PS/;
     return 'FITS' if $magic =~ /^SIMPLE  \=/;
     return 'PNG'  if $magic =~ /^.PNG\r/;
+    return 'XBM'  if $magic =~ /^#define\s+/;
     return chkext(getext($file));    # then try extensions
 }
 
