@@ -362,8 +362,8 @@ sub graticule {
 		    $yp->flat->append($ym->flat)
 	    )->mv(1,0);
     } else {
-	 our $pp = (zeroes($xp)-1); $pp->slice("(-1)") .= 0;
-	 our $pm = (zeroes($xm)-1); $pm->slice("(-1)") .= 0;
+	 our $pp = zeroes($xp)-1; $pp->slice("(-1)") .= 0;
+	 our $pm = zeroes($xm)-1; $pm->slice("(-1)") .= 0;
 
 	if(wantarray) {
 	    return (  pdl( $xp->flat->append($xm->flat),
@@ -466,8 +466,7 @@ sub earth_image {
     }
     last if defined($im);
   }
-  barf("earth_image: $f not found in \@INC\n")
-    unless defined($found);
+  barf("earth_image: $f not found in \@INC\n") if !$found;
   barf("earth_image: couldn't load $f; you may need to install netpbm.\n")
     unless defined($im);
   t_raster2fits()->apply($im);
@@ -1636,7 +1635,7 @@ sub t_sinusoidal {
 @PDL::Transform::Cartography::Conic::ISA = ('PDL::Transform::Cartography');
 sub _c_new {
     my($def_std) = pop;
-    my($me) = new('PDL::Transform::Cartography::Conic',@_); 
+    my $me = PDL::Transform::Cartography::Conic->new(@_);
 
     my($p) = $me->{params};
     $p->{std} = _opt($me->{options},['s','std','standard','Standard'],
